@@ -15,13 +15,18 @@ public class C_TextEndsWith extends C_Expression {
 	protected C_Expression leftArgument;
 	protected C_Expression rightArgument;
 
-	public C_TextEndsWith(){
-		
+	public C_TextEndsWith() {
+
 	}
-	
+
 	public C_TextEndsWith(C_Expression leftArgument, C_Expression rightArgument) {
 		this.leftArgument = leftArgument;
 		this.rightArgument = rightArgument;
+		if (leftArgument != null && rightArgument != null) {
+			this.readableExpression = "TextEndsWith("
+					+ leftArgument.getReadableExpression() + ","
+					+ rightArgument.getReadableExpression() + ")";
+		}
 	}
 
 	public C_OperatorType getOperator() {
@@ -31,7 +36,7 @@ public class C_TextEndsWith extends C_Expression {
 	public String getReturnedDataType() {
 		return "Boolean";
 	}
-	
+
 	@Override
 	public String getId() {
 		return id;
