@@ -4,6 +4,12 @@ import java.util.List;
 
 import org.gcube.portlets.user.td.expressionwidget.shared.expression.C_MultivaluedExpression;
 
+/**
+ * 
+ * @author giancarlo
+ * email: <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
+ *
+ */
 public class C_ConstantList extends C_Leaf implements C_MultivaluedExpression {
 	private static final long serialVersionUID = 222662008523199480L;
 
@@ -14,6 +20,18 @@ public class C_ConstantList extends C_Leaf implements C_MultivaluedExpression {
 	
 	public C_ConstantList(List<TD_Value> arguments) {
 		this.arguments = arguments;
+		String cList=new String();
+		for(TD_Value tdValue:arguments){
+			if(tdValue!=null){
+				if(cList.isEmpty()){
+					cList=cList.concat(tdValue.getReadableExpression());
+				} else {
+					cList=cList.concat(",").concat(tdValue.getReadableExpression());
+				}	
+
+			}
+		}
+		this.readableExpression = "CostantList("+cList+")";
 	}
 	
 	@Override
@@ -36,9 +54,16 @@ public class C_ConstantList extends C_Leaf implements C_MultivaluedExpression {
 	}
 
 	@Override
-	public String toString() {
-		return "C_ConstantList [id=" + id + ", arguments=" + arguments + "]";
+	public String getReadableMultivaluedString() {
+		return readableExpression;
 	}
+	
+	@Override
+	public String toString() {
+		return "ConstantList [id=" + id + ", arguments=" + arguments + "]";
+	}
+
+	
 
 	
 	
