@@ -2,6 +2,12 @@ package org.gcube.portlets.user.td.expressionwidget.shared.model.leaf;
 
 import org.gcube.portlets.user.td.widgetcommonevent.shared.expression.C_Expression;
 
+/**
+ * 
+ * @author giancarlo
+ * email: <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
+ *
+ */
 public class C_Leaf extends C_Expression {
 
 	
@@ -10,7 +16,7 @@ public class C_Leaf extends C_Expression {
 	protected String id="Leaf";
 	
 	public C_Leaf(){
-		
+		this.readableExpression = "Leaf()";
 	}
 	
 	@Override
